==> appfs-21.02.tar.gz: usr/local/www/berogui/includes/menu.php <==
<?php

include_once("/usr/www/include/SQLite2ToSQLite3.php");
require_once('/usr/local/www/berogui/misc/database.php');
require_once('/usr/local/www/berogui/includes/session.php');

$pstn = false;
$has = array(
	'BRI' => false,
	'PRI'	=> false,
	'FXS'	=> false,
	'FXO'	=> false,
	'CAS'	=> false,
	'LTE'	=> false,
	'GSM'	=> false,
);

$db = new beroAri();
$is_sbc_vm = $db->get('is_sbc_vm');

if (!$is_sbc_vm) {
	$has['PRI'] = sqlite_num_rows($db->select("SELECT * from isdn where port_type='PRI'")) > 0;
	$has['BRI'] = sqlite_num_rows($db->select("SELECT * from isdn where port_type='BRI'")) > 0;
	$has['FXS'] = sqlite_num_rows($db->select("SELECT * from analog where port_type='FXS'")) > 0;
	$has['FXO'] = sqlite_num_rows($db->select("SELECT * from analog where port_type='FXO'")) > 0;
	$has['CAS'] = sqlite_num_rows($db->select("SELECT * from cas_channels")) > 0;
	$has['LTE'] = sqlite_num_rows($db->select("SELECT * from lte")) > 0;
	$has['GSM'] = sqlite_num_rows($db->select("SELECT * from gsm ")) > 0;
	foreach ($has as $tech) {
		$pstn |= $tech;
	}
}

if($db->get('gui_mode')=='simple') $simple_class='simple';
if ($_SESSION['beroari_group']=='admin'){
	$ret.= "<nav class='navbar navbar-default' style='margin-top:10px;'>
		<div class='container-fluid'>
    <!-- Brand and toggle get grouped for better mobile display -->
    <div class='navbar-header'>
      <button type='button' class='navbar-toggle collapsed' data-toggle='collapse' data-target='#bs-example-navbar-collapse-1' aria-expanded='false'>
        <span class='sr-only'>Toggle navigation</span>
        <span class='icon-bar'></span>
        <span class='icon-bar'></span>
        <span class='icon-bar'></span>
      </button>
      <a href=\"http://www.beronet.com\" target=\"_blank\" lass='navbar-brand'>
		<img src=\"./includes/images/beroNet.jpg\" alt=\"beroNet\" class=\"png\">
	</a>
    </div>
    <!-- Collect the nav links, forms, and other content for toggling -->
    <div class='collapse navbar-collapse' id='bs-example-navbar-collapse-1'>
      <ul class='nav navbar-nav navbar-right'>
						<li><a href='index.php?m=Dialplan' id='di'>".MENU_DIALPLAN."</a></li>
						<li class='dropdown'><a id='sip' class='dropdown-toggle' data-toggle='dropdown' role='button' aria-haspopup='true' aria-expanded='false'>".MENU_SIP_CAT." <span class='caret'></span></a>
							<ul class='dropdown-menu'>
								<li><a href='index.php?m=Sip' id='s'>".MENU_SIP."</a></li>
								<li class='".$simple_class."'><a href='index.php?m=SipStack' id='sips'>".MENU_SIP_STACKS."</a></li>
								<li><a href='index.php?m=SipLicense' id='siplcsne'>".MENU_SIP_LICENSE."</a></li>
							</ul>
						</li>";
						if ($pstn){
							$ret.= "<li class='dropdown'><a id='pstn' class='dropdown-toggle' data-toggle='dropdown' role='button' aria-haspopup='true' aria-expanded='false'>".MENU_PSTN_CAT." <span class='caret'></span></a>
							<ul class='dropdown-menu'>";
							if ($has['PRI']) $ret.="<li><a href='index.php?m=Isdn&opt=pri' id='isdn-pri'>".MENU_ISDN_PRI."</a></li>";
							if ($has['BRI']) $ret.="<li><a href='index.php?m=Isdn&opt=bri' id='isdn-bri'>".MENU_ISDN_BRI."</a></li>";
							if ($has['FXS']) $ret.="<li><a href='index.php?m=Analog&opt=fxs' id='analog-fxs'>".MENU_ANALOG_FXS."</a></li>";
							if ($has['FXO']) $ret.="<li><a href='index.php?m=Analog&opt=fxo' id='analog-fxo'>".MENU_ANALOG_FXO."</a></li>";
							if ($has['CAS']) $ret.="<li><a href='index.php?m=Cas' id='cas'>".MENU_CAS."</a></li>";
							if ($has['GSM']) $ret.="<li><a href='index.php?m=Gsm' id='gsm'>".MENU_GSM."</a></li>";
							if ($has['LTE']) $ret.="<li><a href='index.php?m=Lte' id='lte'>".MENU_LTE."</a></li>";
							if ($has['GSM'] || $has['LTE']) $ret.="<li><a href='index.php?m=Sms' id='sms'>".MENU_SMS."</a></li>";
							$ret .="<li><a href='index.php?m=PstnHardware' id='sc'>".MENU_HARDWARE."</a></li>";
							$ret.="</ul>
							</li>";
						}
						$ret.="<li class='dropdown'><a id='p' class='dropdown-toggle' data-toggle='dropdown' role='button' aria-haspopup='true' aria-expanded='false'>".MENU_PREFERENCES_CAT." <span class='caret'></span></a>
							<ul class='dropdown-menu'>
								<li><a href='index.php?m=NetConf' id='net'>".MENU_NETWORK."</a></li>";
								if (!$is_sbc_vm) $ret .= "<li><a href='index.php?m=TimeConf' id='time'>".MENU_TIME."</a></li>";
								if (!$is_sbc_vm) $ret .= "<li class='".$simple_class."'><a href='index.php?m=Provisioning' id='prov'>".MENU_PROVISIONING."</a></li>";
								if (!$is_sbc_vm) $ret .= "<li class='".$simple_class."'><a href='index.php?m=Berofos' id='berofos'>".MENU_BEROFOS."</a></li>";
					$ret.="<li class='".$simple_class."'><a href='index.php?m=Logging' id='logging'>".MENU_LOGGING."</a></li>
								<li><a href='index.php?m=Security' id='sec'>".MENU_SECURITY."</a></li>
								<li><a href='index.php?m=Acl' id='acl'>".MENU_ACL."</a></li>
								<li><a href='index.php?m=Dos' id='dos'>".MENU_DOS."</a></li>";
								if ($is_sbc_vm) $ret .= "<li><a href='index.php?m=Vpn' id='info'>".MENU_VPN."</a></li>";
					$ret.="<li class='".$simple_class."'><a href='index.php?m=IsgwCauses' id='causes'>".MENU_ISGW_CAUSES."</a></li>";
								if (!$is_sbc_vm) $ret .= "<li class='".$simple_class."'><a href='index.php?m=CallProgress' id='callprogress'>".MENU_CALL_PROGRESS."</a></li>";
					$ret.="<li><a href='index.php?m=Miscellaneous' id='misc'>".MENU_MISCELLANEOUS."</a></li>
							</ul>
						</li>
						<li class='dropdown'><a id='ma' class='dropdown-toggle' data-toggle='dropdown' role='button' aria-haspopup='true' aria-expanded='false'>".MENU_MANAGEMENT_CAT." <span class='caret'></span></a>
							<ul class='dropdown-menu'>
								<li><a href='index.php?m=State' id='state'>".MENU_STATE."</a></li>
								<li><a href='index.php?m=StateCalls' id='sc'>".MENU_ACTIVE_CALLS."</a></li>
								<li><a href='index.php?m=StateStatistic' id='ss'>".MENU_PORTS_STAT."</a></li>
								<li><a href='index.php?m=BackupRestore' id='br'>".MENU_BACKUP_RES."</a></li>
								<li><a href='index.php?m=UpdateTool' id='up_tool'>". ($is_sbc_vm ? MENU_UPDATE_TOOL_SBCVM : MENU_UPDATE_TOOL) ."</a></li>
								<li><a href='index.php?m=DialplanDebug' id='ddebug'>".MENU_DIALPLAN_DEBUG."</a></li>
								<li><a href='index.php?m=FulltraceGui' id='ftrace'>".MENU_FULL_TRACE."</a></li>
								<li class='$simple_class'><a href='index.php?m=Telnet' id='id_telnet'>".MENU_TELNET."</a></li>
								<li><a href='index.php?m=Info' id='info'>".MENU_INFO."</a></li>";
								if (!$is_sbc_vm) $ret .= "<li class='".$simple_class."'><a href='index.php?m=Cdr' id='cdr'>".MENU_CDR."</a></li>";
					$ret .= "<li><a href='index.php?m=RebootReset' id='rebres'>".MENU_REBOOT_RESET."</a></li>";
								if (!$is_sbc_vm) {
									$ret .= "<li class='$simple_class'><a href='index.php?m=RemoteManagement' id='remoteM'>".MENU_REMOTE_MANAGEMENT."</a></li>"
												.	"<li class='$simple_class'><a href='/app/api/api.php' id='api'>". MENU_API_CALLS ."</a></li>";
								}
					$ret.= "</ul></li>";

				if (!$is_sbc_vm) {
					$directory_not_empty = FALSE;
					if ($dh = @opendir("/home/admin/apps/")) {
                     				while (($file = readdir($dh)) !== false) {
                            				if($file != "." && $file != "..")
								$directory_not_empty = TRUE;
						}
                        			closedir($dh);
                    			}

                                    	$ret.="<li class='dropdown'><a id='apps' class='dropdown-toggle' data-toggle='dropdown' role='button' aria-haspopup='true' aria-expanded='false'>Apps <span class='caret'></span></a>"
					    . "<ul class='dropdown-menu' id='ajax_apps'>";
                                    	if ($directory_not_empty) {
                                        	if ($dh = @opendir("/home/admin/apps/")) {
                                            		while (($file = readdir($dh)) !== false) {
                                                		//$ret.="found file: $file";
                                                		if($file != "." && $file != "..")
                                                    			$ret.="<li><a href='/userapp/$file/index.php'>".$file."</a></li>";
                                            		}
                                            		closedir($dh);
                                        	}
                                    	}
					$ret.="<li><a href='index.php?m=Market' id='market'>".MENU_MARKET."</a></li>";
                                    	$ret.="</ul></li>";
				}
				if (!$is_sbc_vm) {
					$ret .= "<li class='dropdown'>
							<a id='bc' class='dropdown-toggle' data-toggle='dropdown' role='button' aria-haspopup='true' aria-expanded='false'>".MENU_BEROCLOUD."<span class='caret'></span></a>
							<ul class='dropdown-menu'>
								<li style='white-space:nowrap;'><a href='index.php?m=BeroCloud' id='bcs'>".MENU_BEROCLOUD_SETTINGS."</a></li>";
					$ret .=	"<li style='white-space:nowrap;'><a href='https://berocloud.beronet.com' id='bcw' target='_blank'>".MENU_BEROCLOUD_WEBSITE."</a></li>";
					$ret .=		"</ul>
						</li>";
				}
						$ret.="<li><a href='includes/logout.php'>".MENU_LOGOUT."</a></li>
					</ul>
				</div>".
				"</div>".
				"</nav>";

}

?>

==> appfs-24.01.01-rc42.tar.gz: usr/local/www/berogui/includes/menu.php <==
<?php

include_once("/usr/www/include/SQLite2ToSQLite3.php");
require_once('/usr/local/www/berogui/misc/database.php');
require_once('/usr/local/www/berogui/includes/session.php');

$pstn = false;
$has = array(
	'BRI' => false,
	'PRI'	=> false,
	'FXS'	=> false,
	'FXO'	=> false,
	'CAS'	=> false,
	'LTE'	=> false,
	'GSM'	=> false,
);

$db = new beroAri();
$is_sbc_vm = $db->get('is_sbc_vm');

if (!$is_sbc_vm) {
	$has['PRI'] = sqlite_num_rows($db->select("SELECT * from isdn where port_type='PRI'")) > 0;
	$has['BRI'] = sqlite_num_rows($db->select("SELECT * from isdn where port_type='BRI'")) > 0;
	$has['FXS'] = sqlite_num_rows($db->select("SELECT * from analog where port_type='FXS'")) > 0;
	$has['FXO'] = sqlite_num_rows($db->select("SELECT * from analog where port_type='FXO'")) > 0;
	$has['CAS'] = sqlite_num_rows($db->select("SELECT * from cas_channels")) > 0;
	$has['LTE'] = sqlite_num_rows($db->select("SELECT * from lte")) > 0;
	$has['GSM'] = sqlite_num_rows($db->select("SELECT * from gsm ")) > 0;
	foreach ($has as $tech) {
		$pstn |= $tech;
	}
}

if ($db->get('gui_mode') == 'simple') {
	$simple_class='simple';
}

$name_header = '';
$device_name = $db->get('device_name');
if (strlen($device_name)) {
	$weight = 64/14; // min = 1 letter => max margin-left=80px   ||  max = 15 letters => min margin-left=16px;  weight = diff_y / diff_x = diff_px / diff_letters
	$margin = 80 - floor((strlen($device_name) - 1)*($weight));
	$name_header = 	"<div class='navbar-header' style='center'>\n"
								.	"\t<div style='margin-left:{$margin}px;margin-top:15px;font-weight:bold;font-size:15px;color:#8B0000;'>$device_name</div>\n"
								. "</div>\n";
}

if ($_SESSION['beroari_group']=='admin') {
	$ret.= "<nav class='navbar navbar-default' style='margin-top:10px;'>
		<div class='container-fluid'>
    <!-- Brand and toggle get grouped for better mobile display -->
    <div class='navbar-header'>
      <button type='button' class='navbar-toggle collapsed' data-toggle='collapse' data-target='#bs-example-navbar-collapse-1' aria-expanded='false'>
        <span class='sr-only'>Toggle navigation</span>
        <span class='icon-bar'></span>
        <span class='icon-bar'></span>
        <span class='icon-bar'></span>
      </button>
      <a href=\"http://www.beronet.com\" target=\"_blank\" lass='navbar-brand'>
				<img src=\"./includes/images/beroNet.jpg\" alt=\"beroNet\" class=\"png\">
			</a>
		</div>
		$name_header
    <!-- Collect the nav links, forms, and other content for toggling -->
    <div class='collapse navbar-collapse' id='bs-example-navbar-collapse-1'>
      <ul class='nav navbar-nav navbar-right'>
						<li><a href='index.php?m=Dialplan' id='di'>".MENU_DIALPLAN."</a></li>
						<li class='dropdown'><a id='sip' class='dropdown-toggle' data-toggle='dropdown' role='button' aria-haspopup='true' aria-expanded='false'>".MENU_SIP_CAT." <span class='caret'></span></a>
							<ul class='dropdown-menu'>
								<li><a href='index.php?m=Sip' id='s'>".MENU_SIP."</a></li>
								<li class='".$simple_class."'><a href='index.php?m=SipStack' id='sips'>".MENU_SIP_STACKS."</a></li>
								<li><a href='index.php?m=SipLicense' id='siplcsne'>".MENU_SIP_LICENSE."</a></li>
							</ul>
						</li>";
						if ($pstn){
							$ret.= "<li class='dropdown'><a id='pstn' class='dropdown-toggle' data-toggle='dropdown' role='button' aria-haspopup='true' aria-expanded='false'>".MENU_PSTN_CAT." <span class='caret'></span></a>
							<ul class='dropdown-menu'>";
							if ($has['PRI']) $ret.="<li><a href='index.php?m=Isdn&opt=pri' id='isdn-pri'>".MENU_ISDN_PRI."</a></li>";
							if ($has['BRI']) $ret.="<li><a href='index.php?m=Isdn&opt=bri' id='isdn-bri'>".MENU_ISDN_BRI."</a></li>";
							if ($has['FXS']) $ret.="<li><a href='index.php?m=Analog&opt=fxs' id='analog-fxs'>".MENU_ANALOG_FXS."</a></li>";
							if ($has['FXO']) $ret.="<li><a href='index.php?m=Analog&opt=fxo' id='analog-fxo'>".MENU_ANALOG_FXO."</a></li>";
							if ($has['CAS']) $ret.="<li><a href='index.php?m=Cas' id='cas'>".MENU_CAS."</a></li>";
							if ($has['GSM']) $ret.="<li><a href='index.php?m=Gsm' id='gsm'>".MENU_GSM."</a></li>";
							if ($has['LTE']) $ret.="<li><a href='index.php?m=Lte' id='lte'>".MENU_LTE."</a></li>";
							if ($has['GSM'] || $has['LTE']) $ret.="<li><a href='index.php?m=Sms' id='sms'>".MENU_SMS."</a></li>";
							$ret .="<li><a href='index.php?m=PstnHardware' id='sc'>".MENU_HARDWARE."</a></li>";
							$ret.="</ul>
							</li>";
						}
						$ret.="<li class='dropdown'><a id='p' class='dropdown-toggle' data-toggle='dropdown' role='button' aria-haspopup='true' aria-expanded='false'>".MENU_PREFERENCES_CAT." <span class='caret'></span></a>
							<ul class='dropdown-menu'>
								<li><a href='index.php?m=NetConf' id='net'>".MENU_NETWORK."</a></li>";
								if (!$is_sbc_vm) $ret .= "<li><a href='index.php?m=TimeConf' id='time'>".MENU_TIME."</a></li>";
								if (!$is_sbc_vm) $ret .= "<li class='".$simple_class."'><a href='index.php?m=Provisioning' id='prov'>".MENU_PROVISIONING."</a></li>";
								if (!$is_sbc_vm) $ret .= "<li class='".$simple_class."'><a href='index.php?m=Berofos' id='berofos'>".MENU_BEROFOS."</a></li>";
					$ret.="<li class='".$simple_class."'><a href='index.php?m=Logging' id='logging'>".MENU_LOGGING."</a></li>
								<li><a href='index.php?m=Security' id='sec'>".MENU_SECURITY."</a></li>
								<li><a href='index.php?m=Acl' id='acl'>".MENU_ACL."</a></li>
								<li><a href='index.php?m=Dos' id='dos'>".MENU_DOS."</a></li>";
								if ($is_sbc_vm) $ret .= "<li><a href='index.php?m=Vpn' id='info'>".MENU_VPN."</a></li>";
					$ret.="<li class='".$simple_class."'><a href='index.php?m=IsgwCauses' id='causes'>".MENU_ISGW_CAUSES."</a></li>";
								if (!$is_sbc_vm) $ret .= "<li class='".$simple_class."'><a href='index.php?m=CallProgress' id='callprogress'>".MENU_CALL_PROGRESS."</a></li>";
					$ret.="<li><a href='index.php?m=Miscellaneous' id='misc'>".MENU_MISCELLANEOUS."</a></li>
							</ul>
						</li>
						<li class='dropdown'><a id='ma' class='dropdown-toggle' data-toggle='dropdown' role='button' aria-haspopup='true' aria-expanded='false'>".MENU_MANAGEMENT_CAT." <span class='caret'></span></a>
							<ul class='dropdown-menu'>
								<li><a href='index.php?m=State' id='state'>".MENU_STATE."</a></li>
								<li><a href='index.php?m=StateCalls' id='sc'>".MENU_ACTIVE_CALLS."</a></li>
								<li><a href='index.php?m=StateStatistic' id='ss'>".MENU_PORTS_STAT."</a></li>
								<li><a href='index.php?m=BackupRestore' id='br'>".MENU_BACKUP_RES."</a></li>
								<li><a href='index.php?m=UpdateTool' id='up_tool'>". ($is_sbc_vm ? MENU_UPDATE_TOOL_SBCVM : MENU_UPDATE_TOOL) ."</a></li>
								<li><a href='index.php?m=DialplanDebug' id='ddebug'>".MENU_DIALPLAN_DEBUG."</a></li>
								<li><a href='index.php?m=FulltraceGui' id='ftrace'>".MENU_FULL_TRACE."</a></li>
								<li class='$simple_class'><a href='index.php?m=Telnet' id='id_telnet'>".MENU_TELNET."</a></li>
								<li><a href='index.php?m=Info' id='info'>".MENU_INFO."</a></li>";
								if (!$is_sbc_vm) $ret .= "<li class='".$simple_class."'><a href='index.php?m=Cdr' id='cdr'>".MENU_CDR."</a></li>";
					$ret .= "<li><a href='index.php?m=RebootReset' id='rebres'>".MENU_REBOOT_RESET."</a></li>";
								if (!$is_sbc_vm) {
									$ret .= "<li class='$simple_class'><a href='index.php?m=RemoteManagement' id='remoteM'>".MENU_REMOTE_MANAGEMENT."</a></li>"
												.	"<li class='$simple_class'><a href='/app/api/api.php' id='api'>". MENU_API_CALLS ."</a></li>";
								}
					$ret.= "</ul></li>";

				if (!$is_sbc_vm) {
					$directory_not_empty = FALSE;
					if ($dh = @opendir("/home/admin/apps/")) {
                     				while (($file = readdir($dh)) !== false) {
                            				if($file != "." && $file != "..")
								$directory_not_empty = TRUE;
						}
                        			closedir($dh);
                    			}

                                    	$ret.="<li class='dropdown'><a id='apps' class='dropdown-toggle' data-toggle='dropdown' role='button' aria-haspopup='true' aria-expanded='false'>Apps <span class='caret'></span></a>"
					    . "<ul class='dropdown-menu' id='ajax_apps'>";
                                    	if ($directory_not_empty) {
                                        	if ($dh = @opendir("/home/admin/apps/")) {
                                            		while (($file = readdir($dh)) !== false) {
                                                		//$ret.="found file: $file";
                                                		if($file != "." && $file != "..")
                                                    			$ret.="<li><a href='/userapp/$file/index.php'>".$file."</a></li>";
                                            		}
                                            		closedir($dh);
                                        	}
                                    	}
					$ret.="<li><a href='index.php?m=Market' id='market'>".MENU_MARKET."</a></li>";
                                    	$ret.="</ul></li>";
				}
				if (!$is_sbc_vm) {
					$ret .= "<li class='dropdown'>
							<a id='bc' class='dropdown-toggle' data-toggle='dropdown' role='button' aria-haspopup='true' aria-expanded='false'>".MENU_BEROCLOUD."<span class='caret'></span></a>
							<ul class='dropdown-menu'>
								<li style='white-space:nowrap;'><a href='index.php?m=BeroCloud' id='bcs'>".MENU_BEROCLOUD_SETTINGS."</a></li>";
					$ret .=	"<li style='white-space:nowrap;'><a href='https://berocloud.beronet.com' id='bcw' target='_blank'>".MENU_BEROCLOUD_WEBSITE."</a></li>";
					$ret .=		"</ul>
						</li>";
				}
						$ret.="<li><a href='includes/logout.php'>".MENU_LOGOUT."</a></li>
					</ul>
				</div>".
				"</div>".
				"</nav>";

}

?>
